@@ -1,8 +1,15 @@
 window.addEventListener("load", function() {
-    var $ = django.jQuery;
-    var $actions = $('#changelist-form > .actions');
+    if (!django || ! django.jQuery) return;
 
-    var cleanWhitespace = function(element) {
+    const $ = django.jQuery;
+    const $actions = $('#changelist-form > .actions');
+    const $body = $('body');
+
+    if (!$body.hasClass('change-list')) return;
+    if ($body.hasClass('admin_action_buttons')) return;
+    $body.addClass('admin_action_buttons');
+
+    const cleanWhitespace = function(element) {
         for (var i = 0; i < element.childNodes.length; i++) {
             var node = element.childNodes[i];
             if (node.nodeType == 3 && !/\S/.test(node.nodeValue))
@@ -10,18 +17,18 @@ window.addEventListener("load", function() {
         }
     };
 
-    var clickHandler = function(event) {
+    const clickHandler = function(event) {
         event.preventDefault();
-        var button = event.target;
-        var $select = $(button).parent().find('select[name="action"]');
+        const button = event.target;
+        const $select = $(button).parent().find('select[name="action"]');
         $select.val(button.name);
         $select.closest('form').find('button[type="submit"]').click();
 
     };
 
     $actions.each(function() {
-        var $this = $(this);
-        var $select = $this.find('select[name="action"]');
+        const $this = $(this);
+        const $select = $this.find('select[name="action"]');
         if (!$select.length) return;
 
         cleanWhitespace($this[0]);
